Thermo:  Thermodynamics and Phase Equilibrium component of Chemical Engineering Design Library (ChEDL)
======================================================================================================

  .. meta::
      :google-site-verification: wcmDZ88ikLzq1to6urRDGA6R7oIhzya2sN5hOeV1zZw

Contents:

.. toctree::
   :maxdepth: 3

   cubic_equations_of_state
   activity_coefficients
   property_objects
   chemical_package_tutorial
   tutorial_phases_and_flash
   GibbsExcessLiquid_details
   modules
   examples


Installation
------------
.. image:: http://img.shields.io/pypi/v/thermo.svg?style=flat
   :target: https://pypi.python.org/pypi/thermo
   :alt: Version_status
.. image:: http://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat
   :target: https://thermo.readthedocs.io/en/latest/
   :alt: Documentation
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/CalebBell/thermo/blob/master/LICENSE.txt
   :alt: license
.. image:: https://img.shields.io/coveralls/CalebBell/thermo.svg
   :target: https://coveralls.io/github/CalebBell/thermo
   :alt: Coverage
.. image:: https://img.shields.io/pypi/pyversions/thermo.svg
   :target: https://pypi.python.org/pypi/thermo
   :alt: Supported_versions
.. image:: https://badges.gitter.im/CalebBell/thermo.svg
   :alt: Join the chat at https://gitter.im/CalebBell/thermo
   :target: https://gitter.im/CalebBell/thermo
.. image:: https://zenodo.org/badge/62404647.svg
   :alt: Zendo
   :target: https://zenodo.org/badge/latestdoi/62404647


Get the latest version of Thermo from
https://pypi.python.org/pypi/thermo/

If you have an installation of Python with pip, simple install it with:

    $ pip install thermo
    
Alternatively, if you are using `conda <https://conda.io/en/latest/>`_ as your package management, you can simply
install thermo in your environment from `conda-forge <https://conda-forge.org/>`_ channel with:

    $ conda install -c conda-forge thermo

To get the git version, run:

    $ git clone git://github.com/CalebBell/thermo.git

Latest source code
------------------

The latest development version of Thermo's sources can be obtained at

    https://github.com/CalebBell/thermo

Bug reports
-----------

To report bugs, please use the Thermo's Bug Tracker at:

    https://github.com/CalebBell/thermo/issues
    
If you have further questions about the usage of the library, feel free
to contact the author at Caleb.Andrew.Bell@gmail.com.

License information
-------------------

See ``LICENSE.txt`` for information on the terms & conditions for usage
of this software, and a DISCLAIMER OF ALL WARRANTIES.

Although not required by the Thermo license, if it is convenient for you,
please cite Thermo if used in your work. Please also consider contributing
any changes you make back, and benefit the community.


Citation
--------

To cite Thermo in publications use::

    Caleb Bell and Contributors (2016-2021). Thermo: Chemical properties component of Chemical Engineering Design Library (ChEDL)
    https://github.com/CalebBell/thermo.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

